@@ -33,10 +33,10 @@ echo ""
 #プラットフォームをチェック
 if [ ${PLATFORM} = "linux" ]; then
 	EXEC_USER=`/usr/bin/whoami`
-	
+	PS="ps -ef"
 elif [ ${PLATFORM} = "solaris" ]; then
 	EXEC_USER=`/usr/ucb/whoami`
-		
+	PS="/usr/ucb/ps auxwww"
 else
 	echo ""
 	echo "ERROR Environment variavble [PLATFORM] is not correct."
@@ -557,6 +557,11 @@ do
 						# コピー開始
 						echo "Start copying required files."
 						cp -pr $EXEC_PATH/hinemos_agent /opt
+						mkdir /${HINEMOS_AGENT_HOME}/sbin
+						cp -pr $EXEC_PATH/install.cfg ${HINEMOS_AGENT_HOME}/sbin
+						cp -pr $EXEC_PATH/agent_installer_EN.sh ${HINEMOS_AGENT_HOME}/sbin
+						cp -pr $EXEC_PATH/agent_installer_JP.sh ${HINEMOS_AGENT_HOME}/sbin
+						cp -pr $EXEC_PATH/service ${HINEMOS_AGENT_HOME}/sbin
 						
 						#install.cfgの内容を反映してhinemos_agent.cfgをコピー
 						REPLACE_PATH=`echo ${JRE_NAME} | sed 's/\//\\\\\//g'`
@@ -641,12 +646,10 @@ do
 			case ${ANS} in
 				y|Y)
 					#プロセス終了の確認
-					#ps axu | grep /agent/ | grep -v grep | grep hinemos > /dev/null
-					ps -ef | grep /agent/ | grep -v grep | grep hinemos > /dev/null
+					${PS} | grep /agent/ | grep -v grep | grep hinemos > /dev/null
 	  				RET1=$?  
 
-	  				#ps axu | grep /log_agent/ | grep -v grep | grep hinemos > /dev/null 
-	  				ps -ef | grep /log_agent/ | grep -v grep | grep hinemos > /dev/null 
+	  				${PS} | grep /log_agent/ | grep -v grep | grep hinemos > /dev/null 
 	  				RET2=$?  
 				
 					if [ ${RET1} -eq 0 -o ${RET2} -eq 0 ]; then
